diff src/w32xfns.c @ 96361:a99299e4d2de

American English spelling fix.
author Glenn Morris <rgm@gnu.org>
date Fri, 27 Jun 2008 02:13:38 +0000
parents 8971ddf55736
children e038c1a8307c
line wrap: on
line diff
--- a/src/w32xfns.c	Fri Jun 27 02:07:30 2008 +0000
+++ b/src/w32xfns.c	Fri Jun 27 02:13:38 2008 +0000
@@ -46,12 +46,12 @@
      when the input queue is empty, so make it a manual reset event. */
   keyboard_handle = input_available = CreateEvent (NULL, TRUE, FALSE, NULL);
 
   /* interrupt_handle is signalled when quit (C-g) is detected, so that
      blocking system calls can be interrupted.  We make it a manual
      reset event, so that if we should ever have multiple threads
      performing system calls, they will all be interrupted (I'm guessing
      that would the right response).  Note that we use PulseEvent to
-     signal this event, so that it never remains signalled.  */
+     signal this event, so that it never remains signaled.  */
   interrupt_handle = CreateEvent (NULL, TRUE, FALSE, NULL);
 }
 
@@ -75,7 +75,7 @@
 void
 signal_quit ()
 {
   /* Make sure this event never remains signalled; if the main thread
      isn't in a blocking call, then this should do nothing.  */
   PulseEvent (interrupt_handle);
 }
@@ -46,12 +46,12 @@
   keyboard_handle = input_available = CreateEvent (NULL, TRUE, FALSE, NULL);
 
-  /* interrupt_handle is signalled when quit (C-g) is detected, so that
+  /* interrupt_handle is signaled when quit (C-g) is detected, so that
      blocking system calls can be interrupted.  We make it a manual
      reset event, so that if we should ever have multiple threads
@@ -75,7 +75,7 @@
 signal_quit ()
 {
-  /* Make sure this event never remains signalled; if the main thread
+  /* Make sure this event never remains signaled; if the main thread
      isn't in a blocking call, then this should do nothing.  */
   PulseEvent (interrupt_handle);